aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/screen.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/glk/screen.h')
-rw-r--r--engines/glk/screen.h18
1 files changed, 14 insertions, 4 deletions
diff --git a/engines/glk/screen.h b/engines/glk/screen.h
index 541e9e190e..bb5d7f6d25 100644
--- a/engines/glk/screen.h
+++ b/engines/glk/screen.h
@@ -46,10 +46,8 @@ enum STYLES { FONTR, FONTB, FONTI, FONTZ };
*/
class Screen : public Graphics::Screen {
private:
- Common::Array<const Graphics::Font *> _fonts;
-private:
/**
* Load all the fonts
*/
bool loadFonts();
@@ -58,6 +56,13 @@ private:
*/
const Graphics::Font *loadFont(FACES face, Common::Archive *archive,
double size, double aspect, int style);
+protected:
+ Common::Array<const Graphics::Font *> _fonts;
+protected:
+ /**
+ * Load the fonts
+ */
+ virtual void loadFonts(Common::Archive *archive);
public:
/**
* Return the font Id for a given name
@@ -67,7 +72,7 @@ public:
/**
* Constructor
*/
- Screen();
+ Screen() : Graphics::Screen() {}
/**
* Destructor
@@ -75,6 +80,11 @@ public:
virtual ~Screen();
/**
+ * Initialize the screen
+ */
+ void initialize();
+
+ /**
* Fills the screen with a given rgb color
*/
void fill(const byte *rgb);
@@ -46,10 +46,8 @@ enum STYLES { FONTR, FONTB, FONTI, FONTZ };
/**
- * Load all the fonts
+ * Open the fonts archive and load all the fonts
*/
bool loadFonts();